/*************************************************************
* common.h - this file selects which micro specific stuff to
* include and prototypes micro specific functions.
* Copyright YOLD 3173 OpenWii all rights reversed.
**************************************************************/

#ifndef COMMON_H
#define COMMON_H
#include <stdlib.h>

/* Include archdep for whatever chip/conf u have */
#ifdef MSP430
#include "../msp430/archdep.h"
#endif

#ifdef CHIIP
#include "../chiip/archdep.h"
#endif

#ifdef WIIP
#include "../avr/archdep.h"
#endif

#include "serial.h"

/*These functions should be defined in archdep.c*/
inline void machInit(void); //Setup machiene dependand stuff not covered elsewhere
inline void waitus(uint16_t us); //machiene dependant function to wait approx 1ms
inline void msTimerInt(); // This function is called by the timer interrupt (for leds mostly)

/*These are used by both the mn10200 and modchip and come from the jsym file.*/
/*dunno if ill use them or not...*/
extern unsigned char *_memmap __attribute__ ((section ("*ABS*")));


/*We dont even use these but hey, they are here..*/
#define GCFORMAT 	0x0040 gc format
#define WIIFORMAT 	0x0080 wii format
#define NOTSINGLE	0x0100 0-single
#define PTPDISC		0x0200 ptp disc
#define OTPDISC		0x0400 otp disc
#define REALDISC	0x0800 real disc
#define EMUDISC		0x1000 emu disc
#define DISC120		0x4000 0=80mmdisc,1=120mm

/*these should be defined in a single place and included to whatever*/
#define JAP_R 0x00 //is JAP
#define USA_R 0x01 //is USA
#define PAL_R 0x02 //is PAL

#define REGXFERADDR	0x8100	//what address is used to transfer region data to and from dvd drive from microcontroller
#define EEREGADDR 	0x00	//The address in eeprom to used for storing region and other flags
#define EEERASEDSTATE	0xff	//erased value of eeprom data

#ifdef DMS
/*these should be defined by the symbol file..
  but note, if the microcontroller is 16 bit addressing then it may truncate 32 bit addresses to 16 bits. 
  iotw, 0x40bd7a on a AVR will end up as bd7a.. so only 16 bit addresses will work with avr*/
#define UNLOCKADDR 	0x82b6	//p_unlockAddr=0x82b6;
#define STACKRET	0x8f84	//p_stackRet = 0x8f84;
#define ORGRET		0xd4c7	//org_ret=0xd4c7;

/*These symbols are filled in by the linker and give us the starting location and size of the raw mn10200 binary file*/
extern void *_binary_DMS_raw_start;
extern const void _binary_DMS_raw_size;
#define BINARYSTART _binary_DMS_raw_start
#define BINARYSIZE _binary_DMS_raw_size
#endif

#ifdef D2B
#define UNLOCKADDR 	0x82be	//p_unlockAddr=0x82b6;
#define STACKRET	0x8f84	//p_stackRet = 0x8f84;
#define ORGRET		0xd54a	//org_ret=0xd4c7;

extern void *_binary_D2B_raw_start;
extern const void _binary_D2B_raw_size;
#define BINARYSTART _binary_D2B_raw_start
#define BINARYSIZE _binary_D2B_raw_size
#endif

#endif /*COMMON_H*/
